package com.example.afrishop_v3.controllers;

import com.example.afrishop_v3.base.Result;
import com.example.afrishop_v3.enums.ResultCodeEnum;
import com.example.afrishop_v3.models.Activity;
import com.example.afrishop_v3.models.TbCfStationItem;
import com.example.afrishop_v3.repository.ActivityRepository;
import com.example.afrishop_v3.repository.TbCfStationItemRepository;
import org.checkerframework.checker.units.qual.A;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.PageRequest;
import org.springframework.web.bind.annotation.*;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Optional;

/**
 * @Auther: wudepeng
 * @Date: 2020/11/30
 * @Description:活动管理
 */
@RestController
@RequestMapping("/activity")
public class ActivityController {

    private final ActivityRepository activityRepository;
    private final TbCfStationItemRepository itemRepository;

    public ActivityController(ActivityRepository activityRepository, TbCfStationItemRepository itemRepository) {
        this.activityRepository = activityRepository;
        this.itemRepository = itemRepository;
    }

    @GetMapping("/getAllActivity")
    public Result getAllActivity(@RequestParam(value = "pageNum", defaultValue = "0") Integer pageNum,
                                 @RequestParam(value = "pageSize", defaultValue = "12") Integer pageSize) {

        return new Result(activityRepository.getAllActivity(PageRequest.of(pageNum, pageSize)));
    }

    @GetMapping("/info/{id}")
    public Result getActivityInfo(@PathVariable("id") String id) {

        return new Result(activityRepository.findById(id));
    }

    //查询商品活动
    @GetMapping("item/{itemId}")
    public Result getItemActivity(@PathVariable("itemId") String itemId) throws ParseException {
        Result result = new Result();
        Activity activity = null;
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //全场活动
        if (activityRepository.existsByUseType(1)) {
            Optional<Activity> fullAct = activityRepository.findFirstByUseType(1);
            if (fullAct.isPresent()) {
                activity = fullAct.get();
            }
        }

        //商品分类活动
        if (activityRepository.existsByUseType(2)) {
            Optional<TbCfStationItem> byId = itemRepository.findById(itemId);
            if (byId.isPresent()) {
                TbCfStationItem item = byId.get();
                String category1 = item.getItemCategory();
                String category2 = item.getItemCategorytwo();
                String category3 = item.getItemDescritionId();
                String con2 = category1 + "," + category2;
                String con3 = category1 + "," + category2 + "," + category3;
                List<Activity> activityList = activityRepository.findAllByUseType(2);
                for (Activity act2 : activityList) {
                    boolean condition = category1.equals(act2.getCategoryId()) || con2.equals(act2.getCategoryId()) || con3.equals(act2.getCategoryId());
                    if (condition)
                        activity = act2;
                    break;
                }
            }

        }

        //特定商品
        if (activityRepository.existsByUseType(3)) {
            List<Activity> list = activityRepository.findAllByUseType(3);
            for (Activity act3 : list) {
                String[] itemIdArr = act3.getItemIds().split(",");
                List<String> idList = Arrays.asList(itemIdArr);
                if (idList.contains(itemId))
                    activity = act3;
                break;
            }

        }

        if (activity != null) {
            Date endTime = df.parse(activity.getEndTime().toString());
            Date now = df.parse(df.format(new Date()));
            long l = endTime.getTime() - now.getTime();
            long day = l / (24 * 60 * 60 * 1000);
            long hour = (l / (60 * 60 * 1000) - day * 24);
            long min = ((l / (60 * 1000)) - day * 24 * 60 - hour * 60);
            long s = (l / 1000 - day * 24 * 60 * 60 - hour * 60 * 60 - min * 60);
            activity.setDeadline(day + ":" + getTime(hour) + ":" + getTime(min) + ":" + getTime(s));
            result.setData(activity);
            return result;
        }
        result.setCode(ResultCodeEnum.QUERY_ERROR.getCode());
        result.setMessage("No online activity");
        return result;
    }

    public String getTime(long time) {
        String t = String.valueOf(time);
        if (time < 10) {
            t = "0" + time;
        }
        return t;
    }
}
